import 'package:flutter/material.dart';
import 'package:pretty_qr_code/pretty_qr_code.dart';
import 'key_storage.dart';

class DisplayPublicKeyQRCodePage extends StatelessWidget {
  const DisplayPublicKeyQRCodePage({super.key});

  Future<String?> _loadPublicKey() async {
    final keyStorage = KeyStorage();
    return keyStorage.getPublicKey();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.black,
      appBar: AppBar(
        title: const Text('Public Key in QR Code'),
      ),
      body: FutureBuilder<String?>(
        future: _loadPublicKey(),
        builder: (context, snapshot) {
          if (snapshot.connectionState == ConnectionState.waiting) {
            return const Center(child: CircularProgressIndicator());
          }

          final publicKey = snapshot.data;
          if (publicKey == null) {
            return const Center(
              child: Text(
                'No public key found.',
                style: TextStyle(color: Colors.white),
              ),
            );
          }

          return Center(
            child: PrettyQr(
              data: publicKey,
              size: 250,
              roundEdges: true,
              elementColor: Colors.white,
            ),
          );
        },
      ),
    );
  }
}
